@@ -717,7 +717,8 @@ class ContainerLauncher:
                     'Overrides': overrides
                 },
                 'InstancesDistribution': {
-                    'SpotAllocationStrategy': spot_allocation_strategy
+                    'SpotAllocationStrategy': spot_allocation_strategy,
+                    'OnDemandPercentageAboveBaseCapacity': 0
                 }
             }
             self.logger.info(
